;
; ZX81DEF.INC
; include file with definitions and symbols used by Sinclair ZX81
; for FASMZ80 (flatassembler with Z80 instruction set)
;
; V1.0
; (C)opyright by Karl-Heinz Dahlmann, Mnchen
;

; this definitions should not be changed

	NO	EQU	0
	YES	EQU	1
	NEWLINE EQU	$76	; character for NEWLINE
	SPACE	EQU	0	; character for SPACE

if defined MEM_1K
	MEMAVL	EQU	1024
end if
if defined MEM_2K
	MEMAVL	EQU	2048
end if
if defined MEM_4K
	MEMAVL	EQU	4096
end if
if defined MEM_8K
	MEMAVL	EQU	8192
end if
if defined MEM_16K
	MEMAVL	EQU	16384
end if
if defined MEM_32K
	MEMAVL	EQU	32768
end if
if defined MEM_32K
	MEMAVL	EQU	49152
end if

	MEMST	EQU	16384	; begin of memory section of ZX81 (system variables)

; description of flag variable in ZX81
;       BIT 0   leading space in line, 0=permitted / 1=suppress
;       BIT 1   printer in use, 0=no / 1=yes
;       BIT 2   cursor mode, 0=K cursor / 1=L cursor
;       BIT 3
;       BIT 4
;       BIT 5
;       BIT 6   result type, 0=string / 1=numeric
;       BIT 7   syntax check, 0=check syntax only / 1=executing
;
	FLAG_SUPS EQU $01	; suppress space
	FLAG_PRIU EQU $02	; printer using
	FLAG_CURL EQU $04	; cursor L type
	FLAG_NUM  EQU $40	; numeric expression
	FLAG_EXEC EQU $80	; execution

; description of cursor type variable (MODE) in ZX81
;
	CURSOR_KL EQU $00
	CURSOR_F  EQU $01
	CURSOR_G  EQU $02

; margin value for ZX81 (55 for PAL, 50Hz / 31 for NTSC, 60Hz)
;
	PAL  EQU 55
	NTSC EQU 31

; compute and display flag in ZX81
;
;       BIT 0   keystroke, 0=NO / 1=YES
;       BIT 6   fast/slow mode, 0=fast mode / 1=slow mode
;       BIT 7   internal mode using now, 0=fast mode / 1=slow mode

	KEYSTROKE EQU $01
	SLOW_MODE EQU $40
	FAST_MODE EQU $00

; this definitions can be changed regarding hardware used
; change this definitions in source file before including ZX81VARS.INC
; (because changes affects contents of system variables)

; default value for FLAG variable
	DEFFLAG EQU	FLAG_EXEC OR FLAG_NUM
